Usage
btmix(formula, data, k, subset, weights,
nrep = 3, cluster = NULL, control = NULL,
verbose = TRUE, drop = TRUE, unique = FALSE, which = NULL,
type = c("loglin", "logit"), ref = NULL, undecided = NULL,
position = NULL, ...)FLXMCbtreg(formula = . ~ ., type = c("loglin", "logit"), ref = NULL,
undecided = NULL, position = NULL, ...)
Arguments
formula
Symbolic description of the model (of type y ~ 1
or y ~ x).
data, subset
Arguments controlling formula processing.
k
A vector of integers indicating the number of components of
the finite mixture; passed in turn to the k argument
of stepFlexmix. weights
An optional vector of weights to be used in the fitting
process; passed in turn to the weights argument of
flexmix. nrep
Number of runs of the EM algorithm.
cluster
Either a matrix with k columns of initial
cluster membership probabilities for each observation; or a factor
or integer vector with the initial cluster assignments of
observations at the start of the EM algorithm. Default is rando
control
An object of class "FLXcontrol" or a named list;
controls the EM algorithm and passed in turn to the control
argument of flexmix. verbose
A logical; if TRUE progress information is shown
for different starts of the EM algorithm.
drop
A logical; if TRUE and k is of length 1,
then a single raschmix object is returned instead of a
stepRaschmix object.
unique
A logical; if TRUE, then unique() is
called on the result; for details see
stepFlexmix. which
number of model to get if k is a vector of
integers longer than one. If character, interpreted as
number of components or name of an information criterion.
type
Character. Should an auxiliary log-linear Poisson model or
logistic binomial be employed for estimation? The latter is only
available if not undecided effects are estimated.
ref
Character or numeric. Which object parameter should be the
reference category, i.e., constrained to zero?
undecided
Logical. Should an undecided parameter be estimated?
position
Logical. Should a position effect be estimated?