Learn R Programming

psychomix (version 1.1-2)

raschmix-methods: Methods for raschmix Objects

Description

Methods for raschmix-class objects.

Usage

## S3 method for class 'raschmix':
summary(object, eps = 1e-4, ...)

## S3 method for class 'raschmix': parameters(object, which = c("model", "item", "score", "concomitant"), difficulty = TRUE, component = NULL, simplify = TRUE)

## S3 method for class 'raschmix': worth(object, difficulty = TRUE, component = NULL)

## S3 method for class 'raschmix': itempar(object, ref = NULL, alias = TRUE, ...)

scoreProbs(object, component = NULL, simplify = TRUE)

Arguments

object
An object of class "raschmix".
eps
Probabilities below this threshold are treated as zero in the summary method.
which
Indicates which type of parameters are used. model refers to both item and score parameters, item and score to their corresponding parameters separately. The parameters of the concomitant model are access
difficulty
Indicates whether item difficulty (default) or easiness parameters are used.
component
Indicates which components are returned. Default is all components.
ref
a vector of labels or position indices of item parameters or a contrast matrix which should be used as restriction/for normalization. If 'NULL' (the default), all items are used (sum zero restriction).
alias
logical. If 'TRUE' (the default), the aliased parameter is included in the return vector. If 'FALSE', it is removed. If the restriction given in 'ref' depends on several parameters, the first parameter of the restriction specified is (arbitrar
simplify
Should the result be simplified if possible?
...
Currently not used.

Details

worth transforms the item parameters so that the sum over all item parameters (within each component) is zero.

itempar allows for the flexible specification of the restriction applied to the item parameters.

scoreProbs does not include any aliased parameters if a certain raw score is not present in the data.