raschmix-class objects.## S3 method for class 'raschmix':
summary(object, eps = 1e-4, ...)## S3 method for class 'raschmix':
parameters(object,
which = c("model", "item", "score", "concomitant"),
difficulty = TRUE, component = NULL, simplify = TRUE)
## S3 method for class 'raschmix':
worth(object, difficulty = TRUE, component = NULL)
## S3 method for class 'raschmix':
itempar(object, ref = NULL, alias = TRUE, ...)
scoreProbs(object, component = NULL, simplify = TRUE)
"raschmix".model
refers to both item and score parameters, item and
score to their corresponding parameters separately. The
parameters of the concomitant model are accessworth transforms the item parameters so that the sum over all
item parameters (within each component) is zero. itempar allows for the flexible specification of the
restriction applied to the item parameters.
scoreProbs does not include any aliased parameters if a certain
raw score is not present in the data.